@@ -1,7 +1,7 @@
 use std::fmt::Debug;
 
 use regex::Regex;
-use serde::de::DeserializeOwned;
+use serde::{de::DeserializeOwned, Serialize};
 
 pub const EMPTY_BODY_JSON_MSG: &str = "expected a json body but no response body was present";
 pub const EMPTY_BODY_TEXT_MSG: &str = "expected a text body but no response body was present";
@@ -10,8 +10,15 @@ pub const EMPTY_BODY_BYTES_MSG: &str = "expected a response body but no response
 pub const EXPECTED_BODY_PRESENT_MSG: &str = "expected a response body but no response body was present";
 pub const EXPECTED_BODY_ABSENT_MSG: &str = "expected no response body but a response body was present";
 
-pub fn assert_json_body_eq<B>(actual: B, expected: B) where B: DeserializeOwned + PartialEq + Debug + Unpin {
-    assert_eq!(actual, expected, "expected json body {:?} to be equal to {:?} but was not", actual, expected);
+pub fn assert_json_body_eq<B>(actual: B, expected: B) where B: DeserializeOwned + Serialize + PartialEq + Debug + Unpin {
+    assert_eq!(actual, expected, "expected json body '{}' to be equal to '{}' but was not",
+               to_json_string(&actual),
+               to_json_string(&expected));
+}
+
+fn to_json_string<B>(json: &B) -> String where B: DeserializeOwned + Serialize + PartialEq + Debug + Unpin {
+    serde_json::to_string(json)
+        .unwrap_or(String::from("Failed serializing actual response body"))
 }
 
 pub fn assert_text_body(actual: String, expected: String) {
