@@ -26,14 +26,14 @@ mod eq {
 
     #[actix_rt::test]
     async fn result_should_expect_status_eq() {
-        fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
+        async fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
         ok(TestRequest::get().to_http_request()).await.expect_status_eq(200);
     }
 
     #[should_panic(expected = "expected status to be '100' but was '200'")]
     #[actix_rt::test]
     async fn result_expect_status_eq_should_panic() {
-        fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
+        async fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
         ok(TestRequest::get().to_http_request()).await.expect_status_eq(100);
     }
 }
@@ -56,14 +56,14 @@ mod ok {
 
     #[actix_rt::test]
     async fn result_should_expect_status_ok() {
-        fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
+        async fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
         ok(TestRequest::get().to_http_request()).await.expect_status_ok();
     }
 
     #[should_panic(expected = "expected status to be '200' but was '201'")]
     #[actix_rt::test]
     async fn result_expect_status_ok_should_panic() {
-        fn created(_: HttpRequest) -> HttpResponse { HttpResponse::Created().finish() }
+        async fn created(_: HttpRequest) -> HttpResponse { HttpResponse::Created().finish() }
         created(TestRequest::get().to_http_request()).await.expect_status_ok();
     }
 }
@@ -86,14 +86,14 @@ mod created {
 
     #[actix_rt::test]
     async fn result_should_expect_status_created() {
-        fn created(_: HttpRequest) -> HttpResponse { HttpResponse::Created().finish() }
+        async fn created(_: HttpRequest) -> HttpResponse { HttpResponse::Created().finish() }
         created(TestRequest::get().to_http_request()).await.expect_status_created();
     }
 
     #[should_panic(expected = "expected status to be '201' but was '200'")]
     #[actix_rt::test]
     async fn result_expect_status_created_should_panic() {
-        fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
+        async fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
         ok(TestRequest::get().to_http_request()).await.expect_status_created();
     }
 }
@@ -116,14 +116,14 @@ mod accepted {
 
     #[actix_rt::test]
     async fn result_should_expect_status_accepted() {
-        fn accepted(_: HttpRequest) -> HttpResponse { HttpResponse::Accepted().finish() }
+        async fn accepted(_: HttpRequest) -> HttpResponse { HttpResponse::Accepted().finish() }
         accepted(TestRequest::get().to_http_request()).await.expect_status_accepted();
     }
 
     #[should_panic(expected = "expected status to be '202' but was '200'")]
     #[actix_rt::test]
     async fn result_expect_status_accepted_should_panic() {
-        fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
+        async fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
         ok(TestRequest::get().to_http_request()).await.expect_status_accepted();
     }
 }
@@ -146,14 +146,14 @@ mod no_content {
 
     #[actix_rt::test]
     async fn result_should_expect_status_no_content() {
-        fn no_content(_: HttpRequest) -> HttpResponse { HttpResponse::NoContent().finish() }
+        async fn no_content(_: HttpRequest) -> HttpResponse { HttpResponse::NoContent().finish() }
         no_content(TestRequest::get().to_http_request()).await.expect_status_no_content();
     }
 
     #[should_panic(expected = "expected status to be '204' but was '200'")]
     #[actix_rt::test]
     async fn result_expect_status_no_content_should_panic() {
-        fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
+        async fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
         ok(TestRequest::get().to_http_request()).await.expect_status_no_content();
     }
 }
@@ -176,14 +176,14 @@ mod partial_content {
 
     #[actix_rt::test]
     async fn result_should_expect_status_partial_content() {
-        fn partial_content(_: HttpRequest) -> HttpResponse { HttpResponse::PartialContent().finish() }
+        async fn partial_content(_: HttpRequest) -> HttpResponse { HttpResponse::PartialContent().finish() }
         partial_content(TestRequest::get().to_http_request()).await.expect_status_partial_content();
     }
 
     #[should_panic(expected = "expected status to be '206' but was '200'")]
     #[actix_rt::test]
     async fn result_expect_status_partial_content_should_panic() {
-        fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
+        async fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
         ok(TestRequest::get().to_http_request()).await.expect_status_partial_content();
     }
 }
@@ -206,14 +206,14 @@ mod bad_request {
 
     #[actix_rt::test]
     async fn result_should_expect_status_bad_request() {
-        fn bad_request(_: HttpRequest) -> HttpResponse { HttpResponse::BadRequest().finish() }
+        async fn bad_request(_: HttpRequest) -> HttpResponse { HttpResponse::BadRequest().finish() }
         bad_request(TestRequest::get().to_http_request()).await.expect_status_bad_request();
     }
 
     #[should_panic(expected = "expected status to be '400' but was '200'")]
     #[actix_rt::test]
     async fn result_expect_status_bad_request_should_panic() {
-        fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
+        async fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
         ok(TestRequest::get().to_http_request()).await.expect_status_bad_request();
     }
 }
@@ -236,14 +236,14 @@ mod unauthorized {
 
     #[actix_rt::test]
     async fn result_should_expect_status_unauthorized() {
-        fn unauthorized(_: HttpRequest) -> HttpResponse { HttpResponse::Unauthorized().finish() }
+        async fn unauthorized(_: HttpRequest) -> HttpResponse { HttpResponse::Unauthorized().finish() }
         unauthorized(TestRequest::get().to_http_request()).await.expect_status_unauthorized();
     }
 
     #[should_panic(expected = "expected status to be '401' but was '200'")]
     #[actix_rt::test]
     async fn result_expect_status_unauthorized_should_panic() {
-        fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
+        async fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
         ok(TestRequest::get().to_http_request()).await.expect_status_unauthorized();
     }
 }
@@ -266,14 +266,14 @@ mod forbidden {
 
     #[actix_rt::test]
     async fn result_should_expect_status_forbidden() {
-        fn forbidden(_: HttpRequest) -> HttpResponse { HttpResponse::Forbidden().finish() }
+        async fn forbidden(_: HttpRequest) -> HttpResponse { HttpResponse::Forbidden().finish() }
         forbidden(TestRequest::get().to_http_request()).await.expect_status_forbidden();
     }
 
     #[should_panic(expected = "expected status to be '403' but was '200'")]
     #[actix_rt::test]
     async fn result_expect_status_forbidden_should_panic() {
-        fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
+        async fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
         ok(TestRequest::get().to_http_request()).await.expect_status_forbidden();
     }
 }
@@ -296,14 +296,14 @@ mod not_found {
 
     #[actix_rt::test]
     async fn result_should_expect_status_not_found() {
-        fn not_found(_: HttpRequest) -> HttpResponse { HttpResponse::NotFound().finish() }
+        async fn not_found(_: HttpRequest) -> HttpResponse { HttpResponse::NotFound().finish() }
         not_found(TestRequest::get().to_http_request()).await.expect_status_not_found();
     }
 
     #[should_panic(expected = "expected status to be '404' but was '200'")]
     #[actix_rt::test]
     async fn result_expect_status_not_found_should_panic() {
-        fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
+        async fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
         ok(TestRequest::get().to_http_request()).await.expect_status_not_found();
     }
 }
@@ -326,14 +326,14 @@ mod conflict {
 
     #[actix_rt::test]
     async fn result_should_expect_status_conflict() {
-        fn conflict(_: HttpRequest) -> HttpResponse { HttpResponse::Conflict().finish() }
+        async fn conflict(_: HttpRequest) -> HttpResponse { HttpResponse::Conflict().finish() }
         conflict(TestRequest::get().to_http_request()).await.expect_status_conflict();
     }
 
     #[should_panic(expected = "expected status to be '409' but was '200'")]
     #[actix_rt::test]
     async fn result_expect_status_conflict_should_panic() {
-        fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
+        async fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
         ok(TestRequest::get().to_http_request()).await.expect_status_conflict();
     }
 }
@@ -356,14 +356,14 @@ mod gone {
 
     #[actix_rt::test]
     async fn result_should_expect_status_gone() {
-        fn gone(_: HttpRequest) -> HttpResponse { HttpResponse::Gone().finish() }
+        async fn gone(_: HttpRequest) -> HttpResponse { HttpResponse::Gone().finish() }
         gone(TestRequest::get().to_http_request()).await.expect_status_gone();
     }
 
     #[should_panic(expected = "expected status to be '410' but was '200'")]
     #[actix_rt::test]
     async fn result_expect_status_gone_should_panic() {
-        fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
+        async fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
         ok(TestRequest::get().to_http_request()).await.expect_status_gone();
     }
 }
@@ -386,14 +386,14 @@ mod internal_server_error {
 
     #[actix_rt::test]
     async fn result_should_expect_status_internal_server_error() {
-        fn internal_server_error(_: HttpRequest) -> HttpResponse { HttpResponse::InternalServerError().finish() }
+        async fn internal_server_error(_: HttpRequest) -> HttpResponse { HttpResponse::InternalServerError().finish() }
         internal_server_error(TestRequest::get().to_http_request()).await.expect_status_internal_server_error();
     }
 
     #[should_panic(expected = "expected status to be '500' but was '200'")]
     #[actix_rt::test]
     async fn result_expect_status_internal_server_error_should_panic() {
-        fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
+        async fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
         ok(TestRequest::get().to_http_request()).await.expect_status_internal_server_error();
     }
 }
@@ -429,27 +429,27 @@ mod range {
 
     #[actix_rt::test]
     async fn result_should_expect_status_in_inclusive_lower_range() {
-        fn created(_: HttpRequest) -> HttpResponse { HttpResponse::Created().finish() }
+        async fn created(_: HttpRequest) -> HttpResponse { HttpResponse::Created().finish() }
         created(TestRequest::get().to_http_request()).await.expect_status_in_range(201, 300);
     }
 
     #[actix_rt::test]
     async fn result_should_expect_status_in_exclusive_upper_range() {
-        fn created(_: HttpRequest) -> HttpResponse { HttpResponse::Created().finish() }
+        async fn created(_: HttpRequest) -> HttpResponse { HttpResponse::Created().finish() }
         created(TestRequest::get().to_http_request()).await.expect_status_in_range(200, 202);
     }
 
     #[should_panic(expected = "expected status to be in [202;300[ but was '201'")]
     #[actix_rt::test]
     async fn result_expect_status_in_range_should_panic_when_lower() {
-        fn created(_: HttpRequest) -> HttpResponse { HttpResponse::Created().finish() }
+        async fn created(_: HttpRequest) -> HttpResponse { HttpResponse::Created().finish() }
         created(TestRequest::get().to_http_request()).await.expect_status_in_range(202, 300);
     }
 
     #[should_panic(expected = "expected status to be in [200;201[ but was '201'")]
     #[actix_rt::test]
     async fn result_expect_status_in_range_should_panic_when_upper() {
-        fn created(_: HttpRequest) -> HttpResponse { HttpResponse::Created().finish() }
+        async fn created(_: HttpRequest) -> HttpResponse { HttpResponse::Created().finish() }
         created(TestRequest::get().to_http_request()).await.expect_status_in_range(200, 201);
     }
 }
@@ -472,14 +472,14 @@ mod success {
 
     #[actix_rt::test]
     async fn result_should_expect_status_success() {
-        fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
+        async fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
         ok(TestRequest::get().to_http_request()).await.expect_status_success();
     }
 
     #[should_panic(expected = "expected status to be in [200;300[ but was '400'")]
     #[actix_rt::test]
     async fn result_expect_status_success_should_panic_when_not() {
-        fn bad_request(_: HttpRequest) -> HttpResponse { HttpResponse::BadRequest().finish() }
+        async fn bad_request(_: HttpRequest) -> HttpResponse { HttpResponse::BadRequest().finish() }
         bad_request(TestRequest::get().to_http_request()).await.expect_status_success();
     }
 }
@@ -502,14 +502,14 @@ mod redirection {
 
     #[actix_rt::test]
     async fn result_should_expect_status_redirection() {
-        fn moved_permanently(_: HttpRequest) -> HttpResponse { HttpResponse::MovedPermanently().finish() }
+        async fn moved_permanently(_: HttpRequest) -> HttpResponse { HttpResponse::MovedPermanently().finish() }
         moved_permanently(TestRequest::get().to_http_request()).await.expect_status_redirection();
     }
 
     #[should_panic(expected = "expected status to be in [300;400[ but was '400'")]
     #[actix_rt::test]
     async fn result_expect_status_redirection_should_panic_when_not() {
-        fn bad_request(_: HttpRequest) -> HttpResponse { HttpResponse::BadRequest().finish() }
+        async fn bad_request(_: HttpRequest) -> HttpResponse { HttpResponse::BadRequest().finish() }
         bad_request(TestRequest::get().to_http_request()).await.expect_status_redirection();
     }
 }
@@ -532,14 +532,14 @@ mod client_error {
 
     #[actix_rt::test]
     async fn result_should_expect_status_client_error() {
-        fn bad_request(_: HttpRequest) -> HttpResponse { HttpResponse::BadRequest().finish() }
+        async fn bad_request(_: HttpRequest) -> HttpResponse { HttpResponse::BadRequest().finish() }
         bad_request(TestRequest::get().to_http_request()).await.expect_status_client_error();
     }
 
     #[should_panic(expected = "expected status to be in [400;500[ but was '200'")]
     #[actix_rt::test]
     async fn result_expect_status_client_error_should_panic_when_not() {
-        fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
+        async fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
         ok(TestRequest::get().to_http_request()).await.expect_status_client_error();
     }
 }
@@ -562,14 +562,14 @@ mod server_error {
 
     #[actix_rt::test]
     async fn result_should_expect_status_server_error() {
-        fn internal_server_error(_: HttpRequest) -> HttpResponse { HttpResponse::InternalServerError().finish() }
+        async fn internal_server_error(_: HttpRequest) -> HttpResponse { HttpResponse::InternalServerError().finish() }
         internal_server_error(TestRequest::get().to_http_request()).await.expect_status_server_error();
     }
 
     #[should_panic(expected = "expected status to be in [500;600[ but was '200'")]
     #[actix_rt::test]
     async fn result_expect_status_server_error_should_panic_when_not() {
-        fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
+        async fn ok(_: HttpRequest) -> HttpResponse { HttpResponse::Ok().finish() }
         ok(TestRequest::get().to_http_request()).await.expect_status_server_error();
     }
 }
\ No newline at end of file
